@@ -30,7 +30,8 @@ def found(args, data):
 class paginate():
     def __init__(self, session, **kargs):
         self.json = []
-        for page in session.client(kargs.get('service')).get_paginator(kargs.get('ep')).paginate():
+        pargs = {k:v for k,v in kargs.items() if k not in ['ep', 'service', 'fields', 'filter'] if kargs}
+        for page in session.client(kargs.get('service')).get_paginator(kargs.get('ep')).paginate(**pargs):
             self.json = [fields(kargs, i.value) for i in self.jsonpath_expression().find(page) if found(kargs, i.value)]
         self.df = pd.json_normalize(self.json)
 
@@ -63,3 +64,19 @@ class s3_paginate(paginate):
         paginate.__init__(self, session, **kargs)
 
 #####################################
+
+class cw_paginate(paginate):
+    def __init__(self, session, **kargs):
+        kargs.update({'ep':self.name()})
+        kargs.update({'service':'cloudwatch'})
+        paginate.__init__(self, session, **kargs)
+
+#####################################
+
+class ec_paginate(paginate):
+    def __init__(self, session, **kargs):
+        kargs.update({'ep':self.name()})
+        kargs.update({'service':'elasticache'})
+        paginate.__init__(self, session, **kargs)
+
+#####################################
